JSON Hyper schema API
~~~~~~~~~~~~~~~~~~~~~

This page documents the JSON schema API provided by `cubicweb-jsonschema`
under the ``application/schema+json`` content type.


.. include:: application.rst
.. include:: entity-type.rst
.. include:: entity.rst
.. include:: relations.rst
